summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBharath Vignesh J K <52282402+RazCrimson@users.noreply.github.com>2024-06-30 01:33:51 +0530
committerBharath Vignesh J K <52282402+RazCrimson@users.noreply.github.com>2024-06-30 01:33:51 +0530
commit0e1d462c6902329bb141f84ff0954c58edc58a99 (patch)
tree735f30be3527f6ef5cfc94809d393afbedd1289d
parent48103f167ebdcdad6e8e0af666d5a924c4affdf0 (diff)
chg: exports (influxdb) - log warning message if export fails
-rw-r--r--glances/exports/glances_influxdb/__init__.py4
-rw-r--r--glances/exports/glances_influxdb2/__init__.py4
2 files changed, 4 insertions, 4 deletions
diff --git a/glances/exports/glances_influxdb/__init__.py b/glances/exports/glances_influxdb/__init__.py
index b0ae1ee8..cff8012c 100644
--- a/glances/exports/glances_influxdb/__init__.py
+++ b/glances/exports/glances_influxdb/__init__.py
@@ -156,7 +156,7 @@ class Export(GlancesExport):
try:
self.client.write_points(self._normalize(name, columns, points), time_precision="s")
except Exception as e:
- # Log level set to debug instead of error (see: issue #1561)
- logger.debug(f"Cannot export {name} stats to InfluxDB ({e})")
+ # Log level set to warning instead of error (see: issue #1561)
+ logger.warning(f"Cannot export {name} stats to InfluxDB ({e})")
else:
logger.debug(f"Export {name} stats to InfluxDB")
diff --git a/glances/exports/glances_influxdb2/__init__.py b/glances/exports/glances_influxdb2/__init__.py
index 75e7698c..62d90a54 100644
--- a/glances/exports/glances_influxdb2/__init__.py
+++ b/glances/exports/glances_influxdb2/__init__.py
@@ -164,7 +164,7 @@ class Export(GlancesExport):
try:
self.client.write(self.bucket, self.org, self._normalize(name, columns, points), time_precision="s")
except Exception as e:
- # Log level set to debug instead of error (see: issue #1561)
- logger.debug(f"Cannot export {name} stats to InfluxDB ({e})")
+ # Log level set to warning instead of error (see: issue #1561)
+ logger.warning(f"Cannot export {name} stats to InfluxDB ({e})")
else:
logger.debug(f"Export {name} stats to InfluxDB")